aws-ip-ranges
=============

This script retrieves AWS IP ranges data and produces a YAML file formatted
for use by the `aws_firewall <https://github.com/pmuller/puppet-aws_firewall>`_
Puppet module.


Installation
------------

.. code-block:: console

  $ pip install aws-ip-ranges


Development
-----------

To launch tests of the project, use the following command:

.. code-block:: bash

  $ make check
